@@ -1294,7 +1294,7 @@ def _read_buffers(header, buffers, mesh_kwargs, merge_primitives=False, resolver
                     kwargs['frame_to'] = frame_to
                     # append the edge with the mesh frame
                     graph.append(kwargs.copy())
-            else:
+            elif len(geometries) == 1:
                 kwargs["geometry"] = geometries[0]
                 if 'name' in child:
                     kwargs['frame_to'] = names[b]
@@ -1500,6 +1500,10 @@ def _append_material(mat, tree, buffer_items, mat_hashes):
     if isinstance(as_pbr.alphaMode, str):
         result['alphaMode'] = as_pbr.alphaMode
 
+    # if alphaCutoff is defined, export
+    if isinstance(as_pbr.alphaCutoff, float):
+        result['alphaCutoff'] = as_pbr.alphaCutoff
+
     # if doubleSided is defined, export
     if isinstance(as_pbr.doubleSided, bool):
         result['doubleSided'] = as_pbr.doubleSided
