@@ -64,6 +64,9 @@ def load_obj(file_obj,
     # same logic even if they jump directly in to data lines
     text = '\n{}\n'.format(text.strip().replace('\r\n', '\n'))
 
+    # remove backslash continuation characters and merge them into the same line
+    text = text.replace('\\\n', '')
+
     # Load Materials
     materials = {}
     mtl_position = text.find('mtllib')
@@ -100,6 +103,16 @@ def load_obj(file_obj,
     if group_material:
         face_tuples = _group_by_material(face_tuples)
 
+    # no faces but points given
+    # return point cloud
+    if not len(face_tuples) and v is not None:
+        pc = {'vertices': v}
+        if vn is not None:
+            pc['vertex_normals'] = vn
+        if vc is not None:
+            pc['vertex_colors'] = vc
+        return pc
+
     # Load Faces
     # now we have clean- ish faces grouped by material and object
     # so now we have to turn them into numpy arrays and kwargs
@@ -146,7 +159,7 @@ def load_obj(file_obj,
             # i.e. something like:
             #  '31407 31406 31408',
             #  '32303/2469 32304/2469 32305/2469',
-            log.warning('faces have mixed data, using slow fallback!')
+            log.debug('faces have mixed data, using slow fallback!')
             faces, faces_tex, faces_norm = _parse_faces_fallback(face_lines)
 
         # TODO: name usually falls back to something useless
@@ -180,9 +193,9 @@ def load_obj(file_obj,
                 # survive index errors as sometimes we
                 # want materials without UV coordinates
                 uv = vt[mask_vt]
-            except BaseException as E:
+            except BaseException:
+                log.warning('index failed on UV coordinates, skipping!')
                 uv = None
-                raise E
 
             # mask vertices and use new faces
             mesh.update({'vertices': v[mask_v].copy(),
@@ -768,6 +781,8 @@ def export_obj(mesh,
         meshes = [mesh]
     elif util.is_instance_named(mesh, 'Scene'):
         meshes = mesh.dump()
+    elif util.is_instance_named(mesh, 'PointCloud'):
+        meshes = [mesh]
     else:
         raise ValueError('must be Trimesh or Scene!')
 
@@ -775,11 +790,16 @@ def export_obj(mesh,
 
     counts = {'v': 0, 'vn': 0, 'vt': 0}
 
+    tex_data = None
+
     for mesh in meshes:
         # we are going to reference face_formats with this
         face_type = ['v']
         # OBJ includes vertex color as RGB elements on the same line
-        if include_color and mesh.visual.kind in ['vertex', 'face']:
+        if (include_color and
+            mesh.visual.kind in ['vertex', 'face'] and
+                len(mesh.visual.vertex_colors)):
+
             # create a stacked blob with position and color
             v_blob = np.column_stack((
                 mesh.vertices,
@@ -797,43 +817,55 @@ def export_obj(mesh,
                 row_delim='\nv ',
                 digits=digits)])
         # only include vertex normals if they're already stored
-        if include_normals and 'vertex_normals' in mesh._cache.cache:
-            # if vertex normals are stored in cache export them
-            face_type.append('vn')
-            export.append('vn ' + util.array_to_string(
-                mesh.vertex_normals,
-                col_delim=' ',
-                row_delim='\nvn ',
-                digits=digits))
+        if include_normals and mesh._cache.cache.get('vertex_normals') is not None:
+
+            try:
+                converted = util.array_to_string(
+                    mesh.vertex_normals,
+                    col_delim=' ',
+                    row_delim='\nvn ',
+                    digits=digits)
+                # if vertex normals are stored in cache export them
+                face_type.append('vn')
+                export.append('vn ' + converted)
+            except BaseException:
+                log.debug('failed to convert vertex normals',
+                          exc_info=True)
 
-        tex_data = None
         if include_texture and hasattr(mesh.visual, 'uv'):
-            # if vertex texture exists and is the right shape
-            face_type.append('vt')
-            # add the uv coordinates
-            export.append('vt ' + util.array_to_string(
-                mesh.visual.uv,
-                col_delim=' ',
-                row_delim='\nvt ',
-                digits=digits))
-            material = mesh.visual.material
-            if hasattr(material, 'to_simple'):
-                material = material.to_simple()
-            (tex_data,
-             tex_name,
-             mtl_name) = material.to_obj()
-            # add the reference to the MTL file
-            objects.appendleft('mtllib {}'.format(mtl_name))
-            # add the directive to use the exported material
-            export.appendleft('usemtl {}'.format(tex_name))
+            try:
+                material = mesh.visual.material
+                if hasattr(material, 'to_simple'):
+                    material = material.to_simple()
+                (tex_data,
+                 tex_name,
+                 mtl_name) = material.to_obj()
+                converted = util.array_to_string(
+                    mesh.visual.uv,
+                    col_delim=' ',
+                    row_delim='\nvt ',
+                    digits=digits)
+                # if vertex texture exists and is the right shape
+                face_type.append('vt')
+                # add the uv coordinates
+                export.append('vt ' + converted)
+                # add the reference to the MTL file
+                objects.appendleft('mtllib {}'.format(mtl_name))
+                # add the directive to use the exported material
+                export.appendleft('usemtl {}'.format(tex_name))
+            except BaseException:
+                log.debug('failed to convert UV coordinates',
+                          exc_info=True)
+
         # the format for a single vertex reference of a face
         face_format = face_formats[tuple(face_type)]
-        # add the exported faces to the export
-        export.append('f ' + util.array_to_string(
-            mesh.faces + 1 + counts['v'],
-            col_delim=' ',
-            row_delim='\nf ',
-            value_format=face_format))
+        # add the exported faces to the export if available
+        if hasattr(mesh, 'faces'):
+            export.append('f ' + util.array_to_string(
+                mesh.faces + 1 + counts['v'],
+                col_delim=' ',
+                row_delim='\nf ',
+                value_format=face_format))
         # offset our vertex position
         counts['v'] += len(mesh.vertices)
 
