@@ -276,36 +276,42 @@ def export_ply(mesh,
     templates = resources.get('ply.template', decode_json=True)
     # start collecting elements into a string for the header
     header = [templates['intro']]
-    header.append(templates['vertex'])
 
-    # if we're exporting vertex normals add them
-    # to the header and dtype
-    if vertex_normal:
-        header.append(templates['vertex_normal'])
-        dtype_vertex.append(dtype_vertex_normal)
+    # check if scene has geometry
+    if hasattr(mesh, 'vertices'):
+        header.append(templates['vertex'])
 
-    # if mesh has a vertex coloradd it to the header
-    if mesh.visual.kind == 'vertex' and encoding != 'ascii':
-        header.append(templates['color'])
-        dtype_vertex.append(dtype_color)
+        num_vertices = len(mesh.vertices)
+        # if we're exporting vertex normals add them
+        # to the header and dtype
+        if vertex_normal:
+            header.append(templates['vertex_normal'])
+            dtype_vertex.append(dtype_vertex_normal)
 
-    if include_attributes and hasattr(mesh, 'vertex_attributes'):
-        add_attributes_to_header(header, mesh.vertex_attributes)
-        add_attributes_to_dtype(dtype_vertex, mesh.vertex_attributes)
+        # if mesh has a vertex color add it to the header
+        if mesh.visual.kind == 'vertex':
+            header.append(templates['color'])
+            dtype_vertex.append(dtype_color)
 
-    # create and populate the custom dtype for vertices
-    vertex = np.zeros(len(mesh.vertices),
-                      dtype=dtype_vertex)
-    vertex['vertex'] = mesh.vertices
-    if vertex_normal:
-        vertex['normals'] = mesh.vertex_normals
-    if mesh.visual.kind == 'vertex':
-        vertex['rgba'] = mesh.visual.vertex_colors
+        if include_attributes and hasattr(mesh, 'vertex_attributes'):
+            add_attributes_to_header(header, mesh.vertex_attributes)
+            add_attributes_to_dtype(dtype_vertex, mesh.vertex_attributes)
 
-    if include_attributes and hasattr(mesh, 'vertex_attributes'):
-        add_attributes_to_data_array(vertex, mesh.vertex_attributes)
+        # create and populate the custom dtype for vertices
+        vertex = np.zeros(num_vertices,
+                          dtype=dtype_vertex)
+        vertex['vertex'] = mesh.vertices
+        if vertex_normal:
+            vertex['normals'] = mesh.vertex_normals
+        if mesh.visual.kind == 'vertex' and len(mesh.visual.vertex_colors):
+            vertex['rgba'] = mesh.visual.vertex_colors
 
-    header_params = {'vertex_count': len(mesh.vertices),
+        if include_attributes and hasattr(mesh, 'vertex_attributes'):
+            add_attributes_to_data_array(vertex, mesh.vertex_attributes)
+    else:
+        num_vertices = 0
+
+    header_params = {'vertex_count': num_vertices,
                      'encoding': encoding}
 
     if hasattr(mesh, 'faces'):
@@ -334,18 +340,17 @@ def export_ply(mesh,
         header_params).encode('utf-8')
 
     if encoding == 'binary_little_endian':
-        export += vertex.tobytes()
+        if hasattr(mesh, 'vertices'):
+            export += vertex.tobytes()
         if hasattr(mesh, 'faces'):
             export += faces.tobytes()
     elif encoding == 'ascii':
-        export_data = util.structured_array_to_string(vertex,
-                                                      col_delim=' ',
-                                                      row_delim='\n')
+        export_data = util.structured_array_to_string(
+            vertex, col_delim=' ', row_delim='\n')
         if hasattr(mesh, 'faces'):
             export_data += '\n'
-            export_data += util.structured_array_to_string(faces,
-                                                           col_delim=' ',
-                                                           row_delim='\n')
+            export_data += util.structured_array_to_string(
+                faces, col_delim=' ', row_delim='\n')
         export += export_data.encode('utf-8')
     else:
         raise ValueError('encoding must be ascii or binary!')
@@ -463,15 +468,19 @@ def elements_to_kwargs(elements,
 
     kwargs = {'metadata': {'ply_raw': elements}}
 
-    vertices = np.column_stack([elements['vertex']['data'][i]
-                                for i in 'xyz'])
+    if 'vertex' in elements and elements['vertex']['length']:
+        vertices = np.column_stack([elements['vertex']['data'][i]
+                                    for i in 'xyz'])
+        if not util.is_shape(vertices, (-1, 3)):
+            raise ValueError('Vertices were not (n,3)!')
+    else:
+        # return empty geometry if there are no vertices
+        kwargs['geometry'] = {}
+        return kwargs
 
-    if not util.is_shape(vertices, (-1, 3)):
-        raise ValueError('Vertices were not (n,3)!')
-
-    try:
+    if 'face' in elements and elements['face']['length']:
         face_data = elements['face']['data']
-    except (KeyError, ValueError):
+    else:
         # some PLY files only include vertices
         face_data = None
         faces = None
@@ -570,31 +579,10 @@ def elements_to_kwargs(elements,
     kwargs['vertices'] = vertices
 
     # if both vertex and face color are defined pick the one
-    # with the most "signal," i.e. which one is not all zeros
-    colors = []
-    signal = []
-    if faces is not None:
-        # extract face colors or None
-        f_color, f_signal = element_colors(elements['face'])
-        colors.append({'face_colors': f_color})
-        signal.append(f_signal)
-        # extract vertex colors or None
-        v_color, v_signal = element_colors(elements['vertex'])
-        colors.append({'vertex_colors': v_color})
-        signal.append(v_signal)
-
-        if prefer_color is None:
-            # if we are in "auto-pick" mode take the one with the
-            # largest  standard deviation of colors
-            kwargs.update(colors[np.argmax(signal)])
-        elif 'vert' in prefer_color and v_color is not None:
-            # vertex colors are preferred and defined
-            kwargs['vertex_colors'] = v_color
-        elif 'face' in prefer_color and f_color is not None:
-            # face colors are preferred and defined
-            kwargs['face_colors'] = f_color
-    else:
-        kwargs['colors'] = element_colors(elements['vertex'])[0]
+    if 'face' in elements:
+        kwargs['face_colors'] = element_colors(elements['face'])
+    if 'vertex' in elements:
+        kwargs['vertex_colors'] = element_colors(elements['vertex'])
 
     return kwargs
 
@@ -619,13 +607,9 @@ def element_colors(element):
     keys = ['red', 'green', 'blue', 'alpha']
     candidate_colors = [element['data'][i]
                         for i in keys if i in element['properties']]
-
     if len(candidate_colors) >= 3:
-        colors = np.column_stack(candidate_colors)
-        signal = colors.std(axis=0).sum()
-        return colors, signal
-
-    return None, 0.0
+        return np.column_stack(candidate_colors)
+    return None
 
 
 def load_element_different(properties, data):
